import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _PropTypes from 'prop-types';

/* eslint-disable react/sort-comp, react/no-multi-comp */
import React, { Component } from 'react';
import { FocusScope, withRenderTarget } from '@atlaskit/layer-manager';
import Layer from '@atlaskit/layer';
import { layers } from '@atlaskit/theme';

import { Dialog, DialogBody, DialogPositioner, FillScreen } from '../styled/Dialog';
import { TargetOverlay, TargetOuter, TargetInner } from '../styled/Target';
import withScrollMeasurements from '../hoc/withScrollMeasurements';

/* eslint-disable react/prop-types, react/no-danger */
var Clone = function Clone(_ref) {
  var html = _ref.html;
  return React.createElement('div', {
    dangerouslySetInnerHTML: { __html: html },
    style: { pointerEvents: 'none' }
  });
};
/* eslint-enable react/prop-types, react/no-danger */

var Spotlight = function (_Component) {
  _inherits(Spotlight, _Component);

  function Spotlight() {
    var _temp, _this, _ret;

    _classCallCheck(this, Spotlight);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.handleTargetClick = function (event) {
      var _this$props = _this.props,
          targetOnClick = _this$props.targetOnClick,
          target = _this$props.target;


      targetOnClick({ event: event, target: target });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Spotlight.prototype.renderTargetClone = function renderTargetClone() {
    // NOTE: `clone` & `rect` are NOT public API
    var _props = this.props,
        clone = _props.clone,
        pulse = _props.pulse,
        rect = _props.rect,
        target = _props.target,
        targetBgColor = _props.targetBgColor,
        targetOnClick = _props.targetOnClick,
        targetRadius = _props.targetRadius,
        Replacement = _props.targetReplacementComponent;


    if (!target) {
      throw Error('Spotlight couldn\'t find a target matching "' + target + '".');
    }

    return Replacement ? React.createElement(Replacement, rect) : React.createElement(
      TargetOuter,
      { style: rect },
      React.createElement(
        TargetInner,
        { pulse: pulse, bgColor: targetBgColor, radius: targetRadius, style: rect },
        React.createElement(Clone, { html: clone }),
        React.createElement(TargetOverlay, { onClick: targetOnClick && this.handleTargetClick })
      )
    );
  };

  Spotlight.prototype.render = function render() {
    // NOTE: `scrollY` is NOT public API, so is undocumented
    var _props2 = this.props,
        children = _props2.children,
        dialogAppearance = _props2.dialogAppearance,
        dialogPlacement = _props2.dialogPlacement,
        dialogWidth = _props2.dialogWidth,
        footer = _props2.footer,
        header = _props2.header,
        scrollY = _props2.scrollY,
        target = _props2.target;

    // If an appearance is supplied use that. Otherwise use help when a target
    // is present and default when modal

    var appearance = dialogAppearance || (target ? 'help' : 'default');

    // If a custom width (number or percentage) is supplied, set inline style
    // otherwise allow styled component to consume as named prop
    var size = dialogWidth || (target ? 'small' : 'medium');

    var dialog = React.createElement(
      FocusScope,
      null,
      React.createElement(
        Dialog,
        {
          appearance: appearance,
          size: size,
          tabIndex: '-1'
        },
        header,
        React.createElement(
          DialogBody,
          null,
          children
        ),
        footer
      )
    );

    return React.createElement(
      FillScreen,
      { 'in': true, scrollDistance: scrollY },
      target ? React.createElement(
        Layer,
        {
          boundariesElement: 'scrollParent',
          content: dialog,
          offset: '0 8',
          position: dialogPlacement,
          zIndex: layers.spotlight(this.props)
        },
        this.renderTargetClone()
      ) : React.createElement(
        DialogPositioner,
        { 'in': true, size: size },
        dialog
      )
    );
  };

  return Spotlight;
}(Component);

Spotlight.propTypes = {
  /** The elements rendered in the modal */
  children: _PropTypes.any.isRequired /** The appearance of the dialog */
  ,
  dialogAppearance: _PropTypes.oneOf(['help', 'default']) /** Where the dialog should appear, relative to the contents of the children. */
  ,
  dialogPlacement: _PropTypes.oneOf(['top left', 'top center', 'top right', 'right top', 'right middle', 'right bottom', 'bottom left', 'bottom center', 'bottom right', 'left top', 'left middle', 'left bottom']) /** width of the dialog */
  ,
  dialogWidth: _PropTypes.oneOfType([_PropTypes.number, _PropTypes.oneOf(['small']), _PropTypes.oneOf(['medium'])]) /** Optional element rendered below the body */
  ,
  footer: _PropTypes.any /** Optional element rendered above the body */
  ,
  header: _PropTypes.any /** whether or not to display a pulse animation around the spotlighted element */
  ,
  pulse: _PropTypes.bool /** the name of the SpotlightTarget */
  ,
  target: _PropTypes.string /** the background color of the element being highlighted */
  ,
  targetBgColor: _PropTypes.string /** The elements rendered in the modal */
  ,
  targetOnClick: _PropTypes.func /** the border-radius of the element being highlighted */
  ,
  targetRadius: _PropTypes.number /** alternative element to render than the wrapped target */
  ,
  targetReplacementComponent: _PropTypes.any
} /* eslint-disable react/prop-types, react/no-danger */;
Spotlight.defaultProps = {
  pulse: true
};


export default withScrollMeasurements(withRenderTarget({
  target: 'spotlight',
  wrapWithTransitionGroup: false
}, Spotlight));