import _classCallCheck from 'babel-runtime/helpers/classCallCheck';

var SpotlightRegistry = function () {
  function SpotlightRegistry() {
    _classCallCheck(this, SpotlightRegistry);

    this._store = {};
    this._mounted = [];
    this._eventListeners = {};
  }

  SpotlightRegistry.prototype.notifyChange = function notifyChange(name) {
    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    if (this._eventListeners[name]) {
      this._eventListeners[name].forEach(function (fn) {
        fn.apply(undefined, args);
      });
    }
  };

  SpotlightRegistry.prototype.addChangeListener = function addChangeListener(name, fn) {
    if (!this._eventListeners[name]) {
      this._eventListeners[name] = [];
    }

    this._eventListeners[name].push(fn);
  };

  SpotlightRegistry.prototype.removeChangeListener = function removeChangeListener(name, fn) {
    if (this._eventListeners[name]) {
      this._eventListeners[name] = this._eventListeners[name].filter(function (i) {
        return fn !== i;
      });
    }
  };

  SpotlightRegistry.prototype.add = function add(name, node) {
    this._store[name] = node;
    this.notifyChange('add', name);
  };

  SpotlightRegistry.prototype.get = function get(name) {
    return this._store[name];
  };

  SpotlightRegistry.prototype.remove = function remove(name) {
    if (this._store[name]) {
      delete this._store[name];
      this.notifyChange('remove', name);
    }
  };

  SpotlightRegistry.prototype.mount = function mount(name) {
    this._mounted.push(name);
    this.notifyChange('mount', name);
  };

  SpotlightRegistry.prototype.unmount = function unmount(name) {
    this._mounted = this._mounted.filter(function (i) {
      return name !== i;
    });
    this.notifyChange('unmount', name);
  };

  return SpotlightRegistry;
}();

export default SpotlightRegistry;